@@ -24,14 +24,11 @@ class DefaultExceptionHandler:
 
     def handle_error(self, request, response, error):
         response.status_code = 500
-        # response.body = self.error(pathlib.Path("selfpages").absolute(),
-        #                                          "error-500.html", context={"error": str(error)})
         response.body = self.errors_env.get_template(
             "error-500.html").render({"error": error}).encode()
-    
+
     def handle_404(self, response):
         response.status_code = 404
-        
-        response.body = self.errors_env.get_template("index.html").render().encode()
-
 
+        response.body = self.errors_env.get_template(
+            "error-404.html").render().encode()
